@@ -1,8 +1,5 @@
 package Chart::OFC::AxisLabel;
-{
-  $Chart::OFC::AxisLabel::VERSION = '0.11';
-}
-
+$Chart::OFC::AxisLabel::VERSION = '0.12';
 use strict;
 use warnings;
 
@@ -48,7 +45,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A label for an axis
 
-
+__END__
 
 =pod
 
@@ -58,14 +55,15 @@ Chart::OFC::AxisLabel - A label for an axis
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-  my $label = Chart::OFC::AxisLabel->new( label      => 'Some Text',
-                                          text_color => 'blue',
-                                          text_size  => 15,
-                                        );
+    my $label = Chart::OFC::AxisLabel->new(
+        label      => 'Some Text',
+        text_color => 'blue',
+        text_size  => 15,
+    );
 
 =head1 DESCRIPTION
 
@@ -105,14 +103,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
