@@ -1,8 +1,5 @@
 package Chart::OFC::Dataset::Area;
-{
-  $Chart::OFC::Dataset::Area::VERSION = '0.11';
-}
-
+$Chart::OFC::Dataset::Area::VERSION = '0.12';
 use strict;
 use warnings;
 
@@ -60,7 +57,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A dataset represented as a line with a filled area
 
-
+__END__
 
 =pod
 
@@ -70,24 +67,28 @@ Chart::OFC::Dataset::Area - A dataset represented as a line with a filled area
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-  my $bars = Chart::OFC::Dataset::Area->new( values     => \@numbers,
-                                             dot_size   => 3,
-                                             opacity    => 60,
-                                             color      => 'blue',
-                                             fill_color => 'purple',
-                                             label      => 'Daily Sales in $',
-                                             text_size  => 12,
-                                           );
+    my @numbers = (1, 2, 3);
+    my $bars    = Chart::OFC::Dataset::Area->new(
+        values     => \@numbers,
+        dot_size   => 3,
+        opacity    => 60,
+        color      => 'blue',
+        fill_color => 'purple',
+        label      => 'Daily Sales in $',
+        text_size  => 12,
+    );
 
 =head1 DESCRIPTION
 
 This class contains values to be charted as a dotted line with a
 filled area between the line and the X axis.
 
+=for Pod::Coverage type
+
 =head1 ATTRIBUTES
 
 This class has several attributes which may be passed to the C<new()>
@@ -126,14 +127,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
