@@ -1,8 +1,5 @@
 package Chart::OFC::Dataset::Bar;
-{
-  $Chart::OFC::Dataset::Bar::VERSION = '0.11';
-}
-
+$Chart::OFC::Dataset::Bar::VERSION = '0.12';
 use strict;
 use warnings;
 
@@ -62,7 +59,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A dataset represented as bars
 
-
+__END__
 
 =pod
 
@@ -72,16 +69,18 @@ Chart::OFC::Dataset::Bar - A dataset represented as bars
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-  my $bars = Chart::OFC::Dataset::Bar->new( values     => \@numbers,
-                                            opacity    => 60,
-                                            fill_color => 'purple',
-                                            label      => 'Daily Sales in $',
-                                            text_size  => 12,
-                                          );
+   my @numbers = (1, 2, 3);
+   my $bars    = Chart::OFC::Dataset::Bar->new(
+       values     => \@numbers,
+       opacity    => 60,
+       fill_color => 'purple',
+       label      => 'Daily Sales in $',
+       text_size  => 12,
+   );
 
 =head1 DESCRIPTION
 
@@ -89,6 +88,8 @@ This class contains values to be charted as bars on a grid chart. The
 bars are filled with the specified color, but have no outline or other
 styling.
 
+=for Pod::Coverage type
+
 =head1 ATTRIBUTES
 
 This class has several attributes which may be passed to the C<new()>
@@ -133,14 +134,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
