@@ -1,8 +1,5 @@
 package Chart::OFC::Dataset::Candle;
-{
-  $Chart::OFC::Dataset::Candle::VERSION = '0.11';
-}
-
+$Chart::OFC::Dataset::Candle::VERSION = '0.12';
 use strict;
 use warnings;
 
@@ -25,7 +22,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A dataset represented as a candle for each value
 
-
+__END__
 
 =pod
 
@@ -35,26 +32,26 @@ Chart::OFC::Dataset::Candle - A dataset represented as a candle for each value
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-  my @numbers = ( [ 1, 2, 3 ], [ 3, 2, 1 ] );
-
-  my $hlc =
-      Chart::OFC::Dataset::Candle->new
-          ( values    => \@numbers,
-            width     => 5,
-            color     => 'purple',
-            label     => 'Daily Sales in $',
-            text_size => 12,
-            opacity   => 80,
-          );
+    my @numbers = ( [ 1, 2, 3 ], [ 3, 2, 1 ] );
+    my $candle = Chart::OFC::Dataset::Candle->new(
+        values    => \@numbers,
+        width     => 5,
+        color     => 'purple',
+        label     => 'Daily Sales in $',
+        text_size => 12,
+        opacity   => 80,
+    );
 
 =head1 DESCRIPTION
 
 This class contains values to be charted as candle points on a grid chart.
 
+=for Pod::Coverage type
+
 =head1 ATTRIBUTES
 
 This class has several attributes which may be passed to the C<new()>
@@ -73,14 +70,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
