@@ -1,8 +1,5 @@
 package Chart::OFC::Dataset::FadeBar;
-{
-  $Chart::OFC::Dataset::FadeBar::VERSION = '0.11';
-}
-
+$Chart::OFC::Dataset::FadeBar::VERSION = '0.12';
 use strict;
 use warnings;
 
@@ -26,7 +23,7 @@ __PACKAGE__->meta()->make_immutable();
 
 # ABSTRACT: A dataset represented as "fade" bars
 
-
+__END__
 
 =pod
 
@@ -36,22 +33,26 @@ Chart::OFC::Dataset::FadeBar - A dataset represented as "fade" bars
 
 =head1 VERSION
 
-version 0.11
+version 0.12
 
 =head1 SYNOPSIS
 
-  my $bars = Chart::OFC::Dataset::FadeBar->new( values     => \@numbers,
-                                                opacity    => 60,
-                                                fill_color => 'purple',
-                                                label      => 'Daily Sales in $',
-                                                text_size  => 12,
-                                              );
+    my @numbers = (1, 2, 3);
+    my $bars    = Chart::OFC::Dataset::FadeBar->new(
+        values     => \@numbers,
+        opacity    => 60,
+        fill_color => 'purple',
+        label      => 'Daily Sales in $',
+        text_size  => 12,
+    );
 
 =head1 DESCRIPTION
 
 This class contains values to be charted as bars on a grid chart. The
 bars are filled with the specified color and fade towards their end.
 
+=for Pod::Coverage type
+
 =head1 ATTRIBUTES
 
 This class is a subclass of C<Chart::OFC::Dataset::Bar> and accepts
@@ -67,14 +68,10 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Dave Rolsky.
+This software is Copyright (c) 2014 by Dave Rolsky.
 
 This is free software, licensed under:
 
   The Artistic License 2.0 (GPL Compatible)
 
 =cut
-
-
-__END__
-
