@@ -1,8 +1,5 @@
 package Chart::OFC::Dataset::GlassBar;
-{
-  $Chart::OFC::Dataset::GlassBar::VERSION = '0.11';
-}
-
+$Chart::OFC::Dataset::GlassBar::VERSION = '0.12';
 use strict;
 use warnings;
 
@@ -26,14 +23,18 @@ __PACKAGE__->meta()->make_immutable();
 
 =pod
 
+=for Pod::Coverage type
+
 =head1 SYNOPSIS
 
-  my $bars = Chart::OFC::Dataset::GlassBar->new( values     => \@numbers,
-                                                 opacity    => 60,
-                                                 fill_color => 'purple',
-                                                 label      => 'Daily Sales in $',
-                                                 text_size  => 12,
-                                               );
+    my @numbers = (1, 2, 3);
+    my $bars    = Chart::OFC::Dataset::GlassBar->new(
+        values     => \@numbers,
+        opacity    => 60,
+        fill_color => 'purple',
+        label      => 'Daily Sales in $',
+        text_size  => 12,
+    );
 
 =head1 DESCRIPTION
 
